sqlstore

package
v0.0.0-...-0e24ee4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2016 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddAgent

func AddAgent(a *model.AgentDTO) error

func AddAgentSession

func AddAgentSession(a *model.AgentSession) error

func AddMissingMetricsForAgent

func AddMissingMetricsForAgent(a *model.AgentDTO, m []*model.Metric) error

func AddTask

func AddTask(t *model.TaskDTO) error

func DeleteAgent

func DeleteAgent(id int64, orgId int64) error

func DeleteAgentSession

func DeleteAgentSession(a *model.AgentSession) error

func DeleteAgentSessionsByServer

func DeleteAgentSessionsByServer(server string) error

func DeleteTask

func DeleteTask(id int64, orgId int64) (*model.TaskDTO, error)

func GetAgentById

func GetAgentById(id int64, orgId int64) (*model.AgentDTO, error)

func GetAgentMetrics

func GetAgentMetrics(agent *model.AgentDTO) ([]*model.Metric, error)

func GetAgentSessionsByAgentId

func GetAgentSessionsByAgentId(agentId int64) ([]model.AgentSession, error)

func GetAgentSessionsByServer

func GetAgentSessionsByServer(server string) ([]model.AgentSession, error)

func GetAgentTasks

func GetAgentTasks(agent *model.AgentDTO) ([]*model.TaskDTO, error)

func GetAgents

func GetAgents(query *model.GetAgentsQuery) ([]*model.AgentDTO, error)

func GetAgentsForTask

func GetAgentsForTask(task *model.TaskDTO) ([]int64, error)

func GetMetricById

func GetMetricById(id string, orgId int64) (*model.Metric, error)

func GetMetrics

func GetMetrics(query *model.GetMetricsQuery) ([]*model.Metric, error)

func GetTaskById

func GetTaskById(id int64, orgId int64) (*model.TaskDTO, error)

func GetTasks

func GetTasks(query *model.GetTasksQuery) ([]*model.TaskDTO, error)

func NewEngine

func NewEngine(dbType, dbConnectStr string, enableLog bool)

func RelocateRouteAnyTasks

func RelocateRouteAnyTasks(agent *model.AgentDTO) error

func SetEngine

func SetEngine(engine *xorm.Engine, enableLog bool) (err error)

func UpdateAgent

func UpdateAgent(a *model.AgentDTO) error

func UpdateTask

func UpdateTask(t *model.TaskDTO) error

func ValidateMetrics

func ValidateMetrics(orgId int64, metrics map[string]int64) error

func ValidateTaskRouteConfig

func ValidateTaskRouteConfig(task *model.TaskDTO) error

need to make sure that that the metrics listed in the task can be executed by the agents specified by the route config.

Types

type AgentId

type AgentId struct {
	Id int64
}

Directories

Path Synopsis

Jump to